EXT_TO_TREE_SITTER_LANGUAGE = {
    ".js": "tsx",
    ".jsx": "tsx",
    ".ts": "tsx",
    ".tsx": "tsx",
    ".mjs": "tsx",
    ".py": "python",
    ".rs": "rust",
    ".go": "go",
    ".java": "java",
    ".cpp": "cpp",
    ".cc": "cpp",
    ".cxx": "cpp",
    ".c": "cpp",
    ".h": "cpp",
    ".hpp": "cpp",
    ".cs": "cpp",
    ".rb": "ruby",
    # ".md": "markdown",
    # ".rst": "markdown",
    # ".txt": "markdown",
    # ".erb": "embedded-template",
    # ".ejs": "embedded-template",
    # ".html": "embedded-template",
    ".erb": "html",
    ".ejs": "html",
    ".html": "html",
    ".vue": "html",
    ".php": "php",
}

NAME_TO_TREE_SITTER_LANGUAGE = {
    "javascript": "tsx",
    "typescript": "tsx",
    "python": "python",
    "rust": "rust",
    "go": "go",
    "java": "java",
    "c": "cpp",
    "cpp": "cpp",
    "ruby": "ruby",
    "csharp": "cpp",
    "html": "html",
    "php": "php",
}
