# TODO: Artifact from scope, remove eventually when API is stable
LANGUAGE_TO_LSP_LANGUAGE_MAP = {
    "python": "python",
    "javascript": "typescript",
    "typescript": "typescript",
    "java": "java",
    "rust": "rust",
    "csharp": "csharp",
    "golang": "go",
    "ruby": "ruby",
}
