from withrepo.resources.languages import EXT_TO_LANGUAGE_DATA
from withrepo.resources.tree_sitter import EXT_TO_TREE_SITTER_LANGUAGE

__all__ = ["EXT_TO_LANGUAGE_DATA", "EXT_TO_TREE_SITTER_LANGUAGE"]
